#undef HAVE_VOLATILE
#undef HAVE_BROKEN_READDIR
#undef HAVE_C99_VSNPRINTF
#undef HAVE_ERRNO_DECL
#undef HAVE_LONGLONG
#undef HAVE_OFF64_T
#undef HAVE_REMSH
#undef HAVE_UNSIGNED_CHAR
#undef HAVE_UTIMBUF
#undef HAVE_SIG_ATOMIC_T_TYPE
#undef HAVE_SOCKLEN_T_TYPE
#undef ssize_t
#undef ino_t
#undef ssize_t
#undef loff_t
#undef offset_t
#undef aclent_t
#undef wchar_t
#undef HAVE_CONNECT
#undef HAVE_SHORT_INO_T
#undef WITH_SMBWRAPPER
#undef WITH_AFS
#undef WITH_DFS
#undef SUNOS5
#undef SUNOS4
#undef LINUX
#undef AIX
#undef BSD
#undef IRIX
#undef IRIX6
#undef HPUX
#undef QNX
#undef SCO
#undef OSF1
#undef NEXT2
#undef RELIANTUNIX
#undef HAVE_MMAP
#undef HAVE_FCNTL_LOCK
#undef HAVE_FTRUNCATE_EXTEND
#undef FTRUNCATE_NEEDS_ROOT
#undef HAVE_TRAPDOOR_UID
#undef HAVE_ROOT
#undef HAVE_GETTIMEOFDAY_TZ
#undef HAVE_SOCK_SIN_LEN
#undef STAT_READ_FILSYS
#undef STAT_STATFS2_BSIZE
#undef STAT_STATFS2_FSIZE
#undef STAT_STATFS2_FS_DATA
#undef STAT_STATFS3_OSF1
#undef STAT_STATFS4
#undef STAT_STATVFS
#undef STAT_STATVFS64
#undef HAVE_IFACE_AIX
#undef HAVE_IFACE_IFCONF
#undef HAVE_IFACE_IFREQ
#undef HAVE_CRYPT
#undef HAVE_PUTPRPWNAM
#undef HAVE_SET_AUTH_PARAMETERS
#undef WITH_SYSLOG
#undef WITH_PROFILE
#undef WITH_SSL
#undef WITH_LDAP
#undef WITH_NISPLUS
#undef WITH_TDBPWD
#undef WITH_PAM
#undef WITH_PAM_SMBPASS
#undef WITH_NISPLUS_HOME
#undef WITH_AUTOMOUNT
#undef WITH_SMBMOUNT
#undef HAVE_BROKEN_GETGROUPS
#undef REPLACE_GETPASS
#undef REPLACE_INET_NTOA
#undef HAVE_FILE_MACRO
#undef HAVE_FUNCTION_MACRO
#undef HAVE_SETRESUID_DECL
#undef HAVE_SETRESUID
#undef WITH_NETATALK
#undef WITH_UTMP
#undef WITH_MSDFS
#undef WITH_VFS
#undef HAVE_INO64_T
#undef HAVE_STRUCT_FLOCK64
#undef SIZEOF_INO_T
#undef SIZEOF_OFF_T
#undef STAT_STATVFS64
#undef HAVE_LIBREADLINE
#undef HAVE_KERNEL_SHARE_MODES
#undef HAVE_KERNEL_OPLOCKS_IRIX
#undef HAVE_KERNEL_OPLOCKS_LINUX
#undef HAVE_KERNEL_CHANGE_NOTIFY
#undef HAVE_IRIX_SPECIFIC_CAPABILITIES
#undef HAVE_INT16_FROM_RPC_RPC_H
#undef HAVE_UINT16_FROM_RPC_RPC_H
#undef HAVE_INT32_FROM_RPC_RPC_H
#undef HAVE_UINT32_FROM_RPC_RPC_H
#undef KRB4_AUTH
#undef KRB5_AUTH
#undef SEEKDIR_RETURNS_VOID
#undef HAVE_DIRENT_D_OFF
#undef HAVE_GETSPNAM
#undef HAVE_BIGCRYPT
#undef HAVE_GETPRPWNAM
#undef HAVE_FSTAT64
#undef HAVE_LSTAT64
#undef HAVE_STAT64
#undef HAVE_SETRESGID
#undef HAVE_SETRESGID_DECL
#undef HAVE_SHADOW_H
#undef HAVE_MEMSET
#undef HAVE_STRCASECMP
#undef HAVE_STRUCT_DIRENT64
#undef HAVE_TRUNCATED_SALT
#undef BROKEN_NISPLUS_INCLUDE_FILES
#undef HAVE_RPC_AUTH_ERROR_CONFLICT
#undef HAVE_EXPLICIT_LARGEFILE_SUPPORT
#undef USE_BOTH_CRYPT_CALLS
#undef HAVE_BROKEN_FCNTL64_LOCKS
#undef HAVE_SECURE_MKSTEMP
#undef HAVE_FNMATCH
#undef USE_SETEUID
#undef USE_SETRESUID
#undef USE_SETREUID
#undef USE_SETUIDX
#undef HAVE_LIBDL
#undef SYSCONF_SC_NGROUPS_MAX
#undef HAVE_UT_UT_NAME
#undef HAVE_UT_UT_USER
#undef HAVE_UT_UT_ID
#undef HAVE_UT_UT_HOST
#undef HAVE_UT_UT_TIME
#undef HAVE_UT_UT_TV
#undef HAVE_UT_UT_TYPE
#undef HAVE_UT_UT_PID
#undef HAVE_UT_UT_EXIT
#undef HAVE_UT_UT_ADDR
#undef HAVE_UX_UT_SYSLEN
#undef PUTUTLINE_RETURNS_UTMP
#undef COMPILER_SUPPORTS_LL
#undef HAVE_YP_GET_DEFAULT_DOMAIN
#undef USE_SPINLOCKS
#undef SPARC_SPINLOCKS
#undef INTEL_SPINLOCKS
#undef MIPS_SPINLOCKS
#undef POWERPC_SPINLOCKS
#undef HAVE_POSIX_ACLS
#undef HAVE_ACL_GET_PERM_NP
#undef HAVE_UNIXWARE_ACLS
#undef HAVE_SOLARIS_ACLS
#undef HAVE_IRIX_ACLS
#undef HAVE_AIX_ACLS
#undef HAVE_TRU64_ACLS
#undef HAVE_NO_ACLS
#undef HAVE_LIBPAM
#undef HAVE_ASPRINTF_DECL
#undef HAVE_VASPRINTF_DECL
#undef HAVE_SNPRINTF_DECL
#undef HAVE_VSNPRINTF_DECL
#undef HAVE_UNIXSOCKET
#undef MMAP_BLACKLIST
#undef HAVE_CUPS
#undef WITH_LDAP_SAM
#undef WITH_NISPLUS_SAM
#undef WITH_SMBPASSWD_SAM
#undef WITH_TDB_SAM
#undef LINUX_QUOTAS_1
#undef LINUX_QUOTAS_2
